@@ -1,9 +1,10 @@
 package Mason::Plugin;
-BEGIN {
-  $Mason::Plugin::VERSION = '2.20';
+{
+  $Mason::Plugin::VERSION = '2.21';
 }
 use Mason::PluginRole;
 use Mason::Util qw(can_load);
+use Class::Load;
 
 method requires_plugins ($plugin_class:) {
     return ();
@@ -19,7 +20,7 @@ method get_roles_for_mason_class ($plugin_class: $name) {
     if ( $name eq 'Component' ) {
         push( @roles_to_try, join( "::", $plugin_class, 'Filters' ) );
     }
-    my @roles = grep { Class::MOP::is_class_loaded($_) || can_load($_) } @roles_to_try;
+    my @roles = grep { Class::Load::is_class_loaded($_) || can_load($_) } @roles_to_try;
     return @roles;
 }
 
