@@ -1,6 +1,6 @@
 package Mason::Plugin::DollarDot;
-BEGIN {
-  $Mason::Plugin::DollarDot::VERSION = '2.20';
+{
+  $Mason::Plugin::DollarDot::VERSION = '2.21';
 }
 use Moose;
 with 'Mason::Plugin';
@@ -9,7 +9,7 @@ __PACKAGE__->meta->make_immutable();
 
 1;
 
-
+__END__
 
 =pod
 
@@ -41,10 +41,9 @@ attribute names
 
 =head1 DESCRIPTION
 
-This plugin substitutes C<< $.I<identifier> >> for C<<
-$self->I<identifier> >> in all Perl code inside components, so that C<< $.
->> can be used when referring to attributes and calling methods. The actual
-regex is
+This plugin substitutes C<< $.I<identifier> >> for C<< $self->I<identifier> >>
+in all Perl code inside components, so that C<< $. >> can be used when
+referring to attributes and calling methods. The actual regex is
 
     s/ \$\.([^\W\d]\w*) / \$self->$1 /gx;
 
@@ -56,8 +55,8 @@ C<< $. >> was chosen because of its similar use in Perl 6.
 
 This plugin falls under the heading of gratuitous source filtering, which the
 author generally agrees is Evil. That said, this is a very limited filter, and
-seems unlikely to break any legitimate Perl syntax other than use of the C<<
-$. >> special variable (input line number).
+seems unlikely to break any legitimate Perl syntax other than use of the C<< $.
+>> special variable (input line number).
 
 =head1 BUGS
 
@@ -85,7 +84,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
